<?php
declare(strict_types=1);

namespace Inti\Wp\Provider\Metadata;

use Inti\Provider\AbstractProvider;
use function in_array;

/**
 * Class AbstractProvider
 *
 * @package Inti\Wp\Provider\Metadata
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-wp-provider
 */
abstract class AbstractMetadataProvider extends AbstractProvider implements MetadataProviderInterface
{
    protected array $meta_keys = [];
    protected array $metadata  = [];

    /** @noinspection PhpUnusedParameterInspection */
    protected function fetchMetadata(int $id): array
    {
        return [];
    }

    protected function filter(array $result): array
    {
        $item = parent::filter($result);

        foreach ($item as $key => $value) {
            if (in_array($key, $this->meta_keys)) {
                $metadata[$key] = $value;
                unset($item[$key]);
            }
        }

        $this->metadata[$this->getId($item)] = $metadata ?? null;

        return $item;
    }

    public function hasMetadataKey(string $key): bool
    {
        return in_array($key, $this->meta_keys);
    }

    public function getMetadata(int $id): array
    {
        return $this->metadata[$id] ?? [];
    }
}
