<?php
declare(strict_types=1);

namespace Inti\Wp\Provider\Type\Post;

use DomainException;
use WP_Post_Type;
use function get_post_type_object;
use function sprintf;

/**
 * Class Post
 *
 * @package Inti\Wp\Provider\Type\Post
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-wp-provider
 */
class Post extends AbstractPostType
{
    protected string       $name = 'post';
    protected WP_Post_Type $type;

    protected function __construct()
    {
        parent::__construct();

        $wp_type = get_post_type_object($this->getName());

        if (!$wp_type instanceof WP_Post_Type) {
            throw new DomainException(sprintf(
                "%s: Post type '%s' does not exist.",
                __METHOD__, $this->getName()
            ));
        }

        $this->type = $wp_type;
    }

    public function getLabel(): string
    {
        return $this->type->label;
    }

    public function isBuiltin(): bool
    {
        return true;
    }
}
